@@ -1,7 +1,7 @@
 /*
  * @(#)AbacusC.c
  *
- * Copyright 1992 - 2009  David A. Bagley, bagleyd@tux.org
+ * Copyright 1992 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -24,14 +24,14 @@
 /* Methods string infix calculator file for Abacus */
 #include "AbacusP.h"
 #ifndef WINVER
+extern int signgam;
+#endif
 #include <math.h>
 #ifndef M_PI
 #define M_PI 3.14159265358979323846
 #endif
 #ifndef M_E
 #define M_E 2.7182818284590452354
-extern int signgam;
-#endif
 #endif
 
 /* proposed, implemented only a small portion
@@ -274,7 +274,13 @@ static int nestingLevel = 0;
 static Expression parseExpression;
 #endif
 
-#if 0
+#ifdef WINVER
+static double
+pow(double x, double y)
+{
+	return exp(y * log(x));
+}
+
 static double
 cbrt(double x) /* -inf < x < inf */
 {
