@@ -1,7 +1,7 @@
 /*
  * @(#)AbacusD.c
  *
- * Copyright 1999 - 2009  David A. Bagley, bagleyd@tux.org
+ * Copyright 1999 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * Abacus demo and neat pointers from
  * Copyright 1991 - 1998  Luis Fernandes, elf@ee.ryerson.ca
@@ -437,9 +437,9 @@ setLessons(AbacusWidget w)
 				if ((w->abacusDemo.fp = fopen(lname, "r")) == NULL) {
 					w->abacusDemo.lessons[chapter]--;
 #ifdef DEBUG
-					(void) fprintf(stderr, "Chapter %d, lesson %d\n",
-						chapter,
-						w->abacusDemo.lessons[chapter]);
+					(void) fprintf(stderr, "No Chapter %d, lesson %d, exiting\n",
+						chapter + 1,
+						w->abacusDemo.lessons[chapter] + 1);
 #endif
 					return;
 				}
