@@ -25,7 +25,6 @@
  * I use long long when I can not figure out how to do it by strings,
  * as in Display Base.
  */
-
 #include "AbacusP.h"
 
 #define LONGEST_ROMANNUMERAL "mmmdccclxxxvMMMDCCCLXXXVIII" /* 3,888,888 */
@@ -253,9 +252,6 @@ string2Int(char *buf, int base, char decimalPoint)
 }
 #endif
 
-#ifndef MAX_INT
-#define MAX_INT 9223372036854775807LL
-#endif
 /* Try not to use since this restricts the size of abacus. */
 LONG
 multPower(int m, int x, int n)
