@@ -1,7 +1,7 @@
 /*
  * @(#)AbacusP.h
  *
- * Copyright 1994 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2013  David A. Bagley, bagleyd@tux.org
  *
  * Abacus demo and neat pointers from
  * Copyright 1991 - 1998  Luis Fernandes, elf@ee.ryerson.ca
@@ -29,6 +29,20 @@
 #include "timer.h"
 #include "Abacus.h"
 
+#ifdef HAVE_LONG_LONG
+#define LONG long long
+#ifndef LONG_LONG_MAX
+#define LONG_LONG_MAX 9223372036854775807LL
+#endif
+#define MAX_INT LONG_LONG_MAX
+#else
+#define LONG long
+#ifndef LONG_MAX
+#define LONG_MAX 2147483647L
+#endif
+#define MAX_INT LONG_MAX
+#endif
+
 #ifdef WINVER
 #ifndef DEMOPATH
 #ifdef UNIXDELIM
@@ -68,6 +82,8 @@ extern void toggleRightToLeftAddAbacus(AbacusWidget w);
 extern void toggleRightToLeftMultAbacus(AbacusWidget w);
 extern void enterAbacus(AbacusWidget w);
 extern void leaveAbacus(AbacusWidget w);
+extern void moveAbacusInput(AbacusWidget w,
+        int x, int y, char letter, int control);
 extern Boolean checkSubdeck(AbacusWidget w, int position);
 extern void setAbacusString(AbacusWidget w, int reason, char *string);
 
@@ -82,6 +98,7 @@ extern void showMoreAbacusDemo(AbacusWidget w);
 extern void showChapterAbacusDemo(AbacusWidget w, int chapt);
 
 #else
+extern Pixel darker(AbacusWidget w, Pixel pixel);
 
 #ifdef VMS
 #ifndef DEMOPATH
@@ -96,20 +113,6 @@ extern void showChapterAbacusDemo(AbacusWidget w, int chapt);
 #endif
 #endif
 
-#ifdef HAVE_LONG_LONG
-#define LONG long long
-#ifndef LONG_LONG_MAX
-#define LONG_LONG_MAX 9223372036854775807LL
-#endif
-#define MAX_INT LONG_LONG_MAX
-#else
-#define LONG long
-#ifndef LONG_MAX
-#define LONG_MAX 2147483647L
-#endif
-#define MAX_INT LONG_MAX
-#endif
-
 typedef struct _AbacusClassPart {
 	int         ignore;
 } AbacusClassPart;
@@ -166,7 +169,7 @@ extern AbacusClassRec abacusClassRec;
 #define VFILLCIRCLE(w,dr,c,d,x,y) if (w->abacus.vertical) \
 	{FILLCIRCLE(w,dr,c,d,y,x);} else {FILLCIRCLE(w,dr,c,d,x,y);}
 #define VPOLYGON(w,dr,c,cl,l,n,b1,b2) if (w->abacus.vertical) \
-	{int i,t; for (i=0;i<n;i++) {t=l[i].x; l[i].x=l[i].y; l[i].y=t;} \
+	{int i,t; for (i=0;i<=n;i++) {t=l[i].x; l[i].x=l[i].y; l[i].y=t;} \
 	POLYGON(w,dr,c,cl,l,n,b1,b2);} else {POLYGON(w,dr,c,cl,l,n,b1,b2);}
 #define vfillRectClip(w,dr,c,dx,dy,sx,sy,o,wo,ws) if (w->abacus.vertical) \
 	{fillRectClipX(w,dr,c,dy,dx,sy,sx,o,wo,ws);} else \
