@@ -1,7 +1,7 @@
 /*
  * @(#)AbacusT.c
  *
- * Copyright 2009 - 2010  David A. Bagley, bagleyd@tux.org
+ * Copyright 2009 - 2012  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -1908,7 +1908,7 @@ void teachStepRoot(AbacusWidget w)
 {
 	char buffer2[120] = "";
 	char buffer3[120] = "";
-	Boolean done = False;
+	/*Boolean done = False;*/
 	int bDigit = 0, bValue, cValue = 0;
 	int rPosition = 0, rValue;
 	int rStep = w->abacus.step - 2;
@@ -2037,7 +2037,7 @@ void teachStepRoot(AbacusWidget w)
 			w->abacus.carryStep % 2 == 0)) {
 		aux = 1;
 		w->abacus.state = 0;
-		done = nextPositionLAOField(w, &rPosition, &bDigit,
+		/*done = */(void) nextPositionLAOField(w, &rPosition, &bDigit,
 			((w->abacus.reg >= 1) ? root - 2 : rStep / nSteps));
 		highlightRail(w, aux, rPosition, True);
 		if (w->abacus.carryStep != 0)
@@ -2059,7 +2059,7 @@ void teachStepRoot(AbacusWidget w)
 		aux = 1;
 		w->abacus.carry[1] = w->abacus.carry[0];
 		w->abacus.state = 1;
-		done = nextPositionLAOField(w, &rPosition, &bDigit,
+		/*done = */(void) nextPositionLAOField(w, &rPosition, &bDigit,
 			((w->abacus.reg >= 1) ? root - 2 : rStep / nSteps));
 		setStringBuffer(w, w->abacus.bString, aux,
 			rPosition, w->abacus.lower, w->abacus.upper);
@@ -2132,7 +2132,7 @@ void teachStepRoot(AbacusWidget w)
 			w->abacus.carryStep % 2 == 0))) {
 		aux = 2;
 		w->abacus.state = 0;
-		done = nextPositionRAOField(w, &rPosition, &bDigit,
+		/*done = */(void) nextPositionRAOField(w, &rPosition, &bDigit,
 			w->abacus.auxCount / 2, bSteps / 2);
 		highlightRail(w, aux, rPosition, True);
 		if (w->abacus.carryStep != 0)
@@ -2159,7 +2159,7 @@ void teachStepRoot(AbacusWidget w)
 		if (!w->abacus.rightToLeftAdd)
 			w->abacus.carry[1] = w->abacus.carry[0];
 		w->abacus.state = 1;
-		done = nextPositionRAOField(w, &rPosition, &bDigit,
+		/*done = */(void) nextPositionRAOField(w, &rPosition, &bDigit,
 			w->abacus.auxCount / 2, bSteps / 2);
 		setStringBuffer(w, w->abacus.cString, aux,
 			rPosition, w->abacus.lower, w->abacus.upper);
@@ -2208,7 +2208,7 @@ void teachStepRoot(AbacusWidget w)
 			w->abacus.carryStep % 2 == 0)) {
 		aux = 0;
 		w->abacus.state = 0;
-		done = nextPositionPOField(w, &rPosition, &bDigit,
+		/*done = */(void) nextPositionPOField(w, &rPosition, &bDigit,
 			(rStep % nSteps - 4) / 2);
 		highlightRail(w, aux, rPosition, True);
 		if (w->abacus.carryStep != 0) {
@@ -2238,7 +2238,7 @@ void teachStepRoot(AbacusWidget w)
 		if (!w->abacus.rightToLeftAdd)
 			w->abacus.carry[1] = w->abacus.carry[0];
 		w->abacus.state = 1;
-		done = nextPositionPOField(w, &rPosition, &bDigit,
+		/*done = */(void) nextPositionPOField(w, &rPosition, &bDigit,
 			(rStep % nSteps - 4) / 2);
 		setStringBuffer(w, w->abacus.rString, aux,
 			rPosition, w->abacus.lower, w->abacus.upper);
@@ -2906,7 +2906,7 @@ void testTeachRoot(AbacusWidget w, int startX, int finishX, int max)
 	      epsilon = expFloat(root * places + 1, w->abacus.base);
 	      epsilon2 = expFloat((root - 1) * places + 1, w->abacus.base);
 	      for (side = 0; side <= 1; side++) {
-	        w->abacus.rightToLeftAdd = (side != 0);
+	      		w->abacus.rightToLeftAdd = (side != 0);
 			temp = 1.0;
 			if (root == 3)
 				temp *= factor * x;
@@ -2957,7 +2957,6 @@ void testTeachRoot(AbacusWidget w, int startX, int finishX, int max)
 				exit(-1);
 			}
 #if 0
-		} else {
 			for (y = startY; y < finishY; y++) {
 				(void) sprintf(buffer, "%d%c%d", x, op, y);
 				(void) printf("%s = ", buffer);
